@@ -2,23 +2,22 @@
 # Author:        rmp
 # Maintainer:    rmp
 # Created:       2003-12-12
-# Last Modified: $Date: 2010-11-02 11:37:11 +0000 (Tue, 02 Nov 2010) $ $Author: zerojinx $
-# Id:            $Id: dbi.pm 687 2010-11-02 11:37:11Z zerojinx $
-# Source:        $Source: /nfs/team117/rmp/tmp/Bio-Das-ProServer/Bio-Das-ProServer/lib/Bio/Das/ProServer/SourceHydra/dbi.pm,v $
-# $HeadURL: https://proserver.svn.sourceforge.net/svnroot/proserver/trunk/lib/Bio/Das/ProServer/SourceHydra/dbi.pm $
+# Last Modified: $Date: 2007/02/28 12:23:44 $ $Author: rmp $
+# Id:            $Id: dbi.pm,v 2.52 2007/02/28 12:23:44 rmp Exp $
+# Source:        $Source: /cvsroot/Bio-Das-ProServer/Bio-Das-ProServer/lib/Bio/Das/ProServer/SourceHydra/dbi.pm,v $
+# $HeadURL$
 #
 # DBI-driven sourceadaptor broker
 #
 package Bio::Das::ProServer::SourceHydra::dbi;
 use strict;
 use warnings;
+use base qw(Bio::Das::ProServer::SourceHydra);
 use English qw(-no_match_vars);
 use Carp;
-use base qw(Bio::Das::ProServer::SourceHydra);
-use Readonly;
 
-our $VERSION = do { my ($v) = (q$Revision: 687 $ =~ /\d+/mxsg); $v; };
-Readonly::Scalar our $CACHE_TIMEOUT => 30;
+our $VERSION       = do { my @r = (q$Revision: 2.52 $ =~ /\d+/mxg); sprintf '%d.'.'%03d' x $#r, @r };
+our $CACHE_TIMEOUT = 30;
 
 #########
 # the purpose of this module:
@@ -33,7 +32,7 @@ sub sources {
   # flush the table cache *at most* once every $CACHE_TIMEOUT
   # This may need signal triggering to have immediate support
   #
-  if($now > ($self->{'_tablecache_timestamp'} || 0)+$CACHE_TIMEOUT) {
+  if($now > $self->{'_tablecache_timestamp'}+$CACHE_TIMEOUT) {
     $self->{'debug'} and carp qq(Flushing table-cache for $dsn);
     delete $self->{'_tables'};
     $self->{'_tablecache_timestamp'} = $now;
@@ -52,50 +51,23 @@ sub sources {
       $sth->execute();
 
       $self->{'_tables'} = [map {
-        $dsn.($_->[0] =~ /^.{$l}(.*)$/mxs)[0];
+	my ($remainder) = $_->[0] =~ /^.{$l}(.*)$/mx;
+	$dsn.$remainder;
       } @{$sth->fetchall_arrayref()}];
 
       $sth->finish();
       $self->{'debug'} and carp qq(@{[scalar @{$self->{'_tables'}}]} tables found);
-      1;
+    };
 
-    } or do {
+    if($EVAL_ERROR) {
       carp "Error scanning tables: $EVAL_ERROR";
       delete $self->{'_tables'};
-    };
+    }
   }
 
   return @{$self->{'_tables'} || []};
 }
 
-sub last_modified {
-  my $self = shift;
-
-  if($self->transport->dbh->{Driver}->{Name} ne 'mysql') {
-    return;
-  }
-
-  my $now      = time;
-  my $basename = $self->config->{'basename'};
-
-  #########
-  # flush the timestamp cache *at most* once every $CACHE_TIMEOUT
-  # This may need signal triggering to have immediate support
-  #
-  if($now > ($self->{'_lastmodified_timestamp'} || 0)+$CACHE_TIMEOUT) {
-    $self->{'debug'} and carp qq(Flushing last-modified cache for hydra $self->{'dsn'});
-    $self->{'_lastmodified_timestamp'} = $now;
-    my $server_text = [sort { $b cmp $a } ## no critic
-                     map { $_->{Update_time} }
-                     @{ $self->transport()->query(q(SHOW TABLE STATUS),{Update_time=>1}) }
-                    ]->[0]; # server local time
-    my $server_unix = $self->transport()->query(q(SELECT UNIX_TIMESTAMP(?) as 'unix'), $server_text)->[0]{unix}; # sec since epoch
-    $self->{'_lastmodified'} = $server_unix;
-  }
-
-  return $self->{'_lastmodified'};
-}
-
 1;
 __END__
 
@@ -105,7 +77,7 @@ Bio::Das::ProServer::SourceHydra::dbi - A database-backed implementation of B::D
 
 =head1 VERSION
 
-$Revision: 687 $
+$Revision: 2.52 $
 
 =head1 AUTHOR
 
@@ -140,17 +112,8 @@ disclaimers of warranty.
   This routine caches results for $CACHE_TIMEOUT as show tables can be
   slow for a few thousand sources.
 
-=head2 last_modified : machine time of last data change
-
-  Gets the most recent update time for any of the hydra's tables.
-  Only knows how to do this for MySQL databases.
-
-  my $unixtime = $dbihydra->last_modified();
-
 =head1 DIAGNOSTICS
 
-Run ProServer with the -debug flag.
-
 =head1 CONFIGURATION AND ENVIRONMENT
 
   [mysimplehydra]
@@ -171,6 +134,4 @@ Bio::Das::ProServer::SourceHydra
 
 =head1 BUGS AND LIMITATIONS
 
-The last_modified method only works for MySQL databases.
-
 =cut
